@@ -26,7 +26,6 @@
     limitations under the License.
 """
 
-
 import os
 import tempfile
 
@@ -53,6 +52,12 @@ class MissionSupportSystemDefaultConfig(object):
     Your values can be set in your personal mss_settings.json file
     """
 
+    # layout of different views, with immutable they can't resized
+    layout = {"topview": (963, 702),
+              "sideview": (913, 557),
+              "tableview": (1236, 424),
+              "immutable": False}
+
     # Matplotlib Basemap Projection Parameters
     # The following parameters configure the map projections available in
     # the top view. Define EPSG codes you require in terms of Matplotlib
@@ -178,30 +183,32 @@ class MissionSupportSystemDefaultConfig(object):
                     "abbrev": "geop",
                     "regions": {"Europe": "eur", "Germany": "de"},
                     "levels": [200, 250, 300, 500, 700, 850, 925],
-                    "forecast_steps": range(0, 240, 3)},
+                    "forecast_steps": list(range(0, 240, 3))},
                 "Temperature": {
                     "abbrev": "temp",
                     "regions": {"Europe": "eur", "Germany": "de"},
                     "levels": [200, 250, 300, 500, 700, 850, 925],
-                    "forecast_steps": range(0, 240, 3)},
+                    "forecast_steps": list(range(0, 240, 3))},
                 "Equivalent Potential Temperature": {
                     "abbrev": "eqpt",
                     "regions": {"Europe": "eur", "Germany": "de"},
                     "levels": [500, 700, 850, 925],
-                    "forecast_steps": range(0, 240, 3)},
+                    "forecast_steps": list(range(0, 240, 3))},
                 "Relative Humidity": {
                     "abbrev": "rhu",
                     "regions": {"Europe": "eur", "Germany": "de"},
                     "levels": [200, 250, 300, 500, 700, 850, 925],
-                    "forecast_steps": range(0, 243, 3)},
+                    "forecast_steps": list(range(0, 243, 3))},
                 "Vertical Velocity": {
                     "abbrev": "vert",
                     "regions": {"Europe": "eur", "Germany": "de"},
                     "levels": [200, 250, 300, 500, 700, 850, 925],
-                    "forecast_steps": range(0, 243, 3)}
+                    "forecast_steps": list(range(0, 243, 3))}
             }
         }
     }
+    # None is not wanted here
+    proxies = {}
 
     # Trajectory tool: When NASA Ames files are opened, the following
     # variables will be used for lon/lat/pressure:
