@@ -27,8 +27,11 @@
     limitations under the License.
 """
 
-import datetime
+from __future__ import division
 
+from builtins import str
+
+import datetime
 import logging
 import os
 from mslib.utils import config_loader
@@ -40,7 +43,7 @@ import numpy
 try:
     import nappy
     HAVE_NAPPY = True
-except:
+except ImportError:
     logging.warn("*** NAppy is not available. You will not be able to read NASA Ames files. ***")
     HAVE_NAPPY = False
 
@@ -53,7 +56,7 @@ class LagrantoTreeModelUnsupportedOperationError(Exception):
     pass
 
 
-class AbstractLagrantoDataItem:
+class AbstractLagrantoDataItem(object):
     """Base class for all trajectory instances that are loaded into a
        trajectory tool.
 
@@ -108,7 +111,7 @@ class AbstractLagrantoDataItem:
                 return str(self.gxElements['general']['colour']) + '/' + str(
                     self.gxElements['general']['linestyle']) + '/' + str(
                         self.gxElements['general']['linewidth'])
-            except Exception, ex:
+            except Exception as ex:
                 logging.debug(u"caught a wildcard Exception: {}, {}".format(type(ex), ex))
                 return ''
         elif column == 3:
@@ -116,7 +119,7 @@ class AbstractLagrantoDataItem:
             s = ''
             try:
                 s += u'time({})'.format(self.gxElements['general']['timeMarkerInterval'].strftime('%H:%M'))
-            except Exception, ex:
+            except Exception as ex:
                 logging.debug(u"caught a wildcard Exception: {}, {}".format(type(ex), ex))
             return s
         else:
@@ -228,7 +231,8 @@ class LagrantoMapItem(AbstractLagrantoDataItem):
                     self.lonVariableChild.getVariableData()[0],
                     self.latVariableChild.getVariableData()[0],
                     self.pressureVariableChild.getVariableData()[0])
-            except:
+            except Exception as ex:
+                logging.debug("Wildecard Exception %s - %s.", type(ex), ex)
                 return ''
         else:
             return ''
@@ -270,7 +274,8 @@ class LagrantoMapItem(AbstractLagrantoDataItem):
             self.__computeTimeMarkerIndexes(value)
             try:
                 self.timeSeriesPlotter.update()
-            except:
+            except Exception as ex:
+                logging.debug("Wildecard Exception %s - %s.", type(ex), ex)
                 pass
 
     def __computeTimeMarkerIndexes(self, requestedInterval):
@@ -294,7 +299,8 @@ class LagrantoMapItem(AbstractLagrantoDataItem):
         # value representing seconds.
         try:
             requestedInterval = requestedInterval.hour * 3600 + requestedInterval.minute * 60
-        except:
+        except Exception as ex:
+            logging.debug("Wildecard Exception %s - %s.", type(ex), ex)
             pass
 
         #
@@ -425,7 +431,7 @@ class FlightTrackItem(LagrantoMapItem):
                     # The time variable has to be modified a bit: convert
                     # seconds to hours and change the name correspondingly.
                     index = self.nafile.VNAME.index(item.getName())
-                    self.nafile.V[index, :] = self.nafile.V[index, :] / 3600.
+                    self.nafile.V[index, :] = (self.nafile.V[index, :] / 3600.)
                     self.nafile.VNAME[index] = "(1/3600) * " + self.nafile.VNAME[index]
                     item.itemName = self.nafile.VNAME[index]
                     break
@@ -476,7 +482,7 @@ class FlightTrackItem(LagrantoMapItem):
         try:
             self.nafile = nappy.openNAFile(self.nasFileName)
             self.nafile.readData()
-        except TypeError, ex:  # catch TypeError as nappy itself triggers Exception when raising
+        except TypeError as ex:  # catch TypeError as nappy itself triggers Exception when raising
             self.nafile = None
             logging.error(u"%s %s", type(ex), ex)
             return
@@ -552,8 +558,8 @@ class LagrantoOutputItem(LagrantoMapItem):
         for i, (trajectory, metadata) in enumerate(zip(self.loutput.data,
                                                        self.loutput.meta)):
             trname = "{:04d} ".format(i)
-            if "startcoordinates" in metadata.keys():
-                trname += unicode(
+            if "startcoordinates" in metadata:
+                trname += str(
                     [u"{:.2f}".format(r) for r in metadata["startcoordinates"]]).replace('\'', '')
             TrajectoryItem(trname, True, self, trajectory, metadata)
 
@@ -589,7 +595,7 @@ class TrajectoryItem(LagrantoMapItem):
         #
         # Add all variable names contained in self.data as child nodes, so
         # that they are added to the tree view.
-        for variable in self.data.keys():
+        for variable in self.data:
             #
             # Per default, plot only variables listed here in a new time
             # series window.
@@ -624,7 +630,7 @@ class TrajectoryItem(LagrantoMapItem):
                         self.timeVariableChild.getVariableData()[-1])
         elif column == 6:
             s = ''
-            for key, value in self.metadata.items():
+            for key, value in list(self.metadata.items()):
                 if key not in ["starttime", "file", "starttime_filename",
                                "startcoordinates", "duration"]:
                     s += u"{} = {}, ".format(key, str(value))
@@ -635,7 +641,7 @@ class TrajectoryItem(LagrantoMapItem):
         """
         try:
             return self.metadata["starttime"]
-        except:
+        except KeyError:
             return self.metadata["starttime_filename"]
 
     def getMetadata(self):
@@ -653,7 +659,7 @@ class TrajectoryItem(LagrantoMapItem):
         """
         try:
             return self.metadata[key]
-        except:
+        except KeyError:
             return None
 
 
