@@ -26,6 +26,10 @@
     limitations under the License.
 """
 
+from __future__ import division
+
+from past.builtins import basestring
+
 from abc import ABCMeta, abstractmethod
 import glob
 import re
@@ -39,6 +43,7 @@ import pickle
 
 from mslib import netCDF4tools
 from mslib.mswms.msschem import MSSChemTargets
+from future.utils import with_metaclass
 
 valid_time_cache = None
 # Maximum size of the cache in bytes.
@@ -47,24 +52,24 @@ valid_time_cache_max_size_bytes = 10 * 1024 * 1024
 valid_time_cache_max_age_seconds = 10 * 86400
 
 
-class NWPDataAccess(object):
+class NWPDataAccess(with_metaclass(ABCMeta, object)):
     """Abstract superclass providing a framework to let the user query
        in which data file a given variable at a given time can be found.
 
     The class provides the method get_filename(). It derives filenames from
-    CF variable names, initialisation and valid times.
+    CF variable names, initialisation and valid times.q
     The method get_datapath() provides the root path where the data
     can be found.
 
     In subclasses, the protected method _determine_filename() must be
     implemented.
     """
-    __metaclass__ = ABCMeta
 
     def __init__(self, rootpath):
         """Constructor takes the path of the data directory.
         """
         self._root_path = rootpath
+        self._modelname = ""
 
     def get_filename(self, variable, vartype, init_time, valid_time,
                      fullpath=False):
@@ -116,7 +121,7 @@ class NWPDataAccess(object):
     def md5_filename(self, filename):
         """
         """
-        md5_filename = hashlib.md5(filename + repr(os.path.getmtime(filename))).hexdigest()
+        md5_filename = hashlib.md5((filename + repr(os.path.getmtime(filename))).encode('utf-8')).hexdigest()
         md5_filename += ".vt_cache_pickle"
         return md5_filename
 
@@ -127,9 +132,10 @@ class NWPDataAccess(object):
         filename = os.path.join(valid_time_cache, self.md5_filename(filename))
         if os.path.exists(filename):
             try:
-                with open(filename, "r") as fileobj:
+                # ToDo check Python2
+                with open(filename, "rb") as fileobj:
                     valid_times = pickle.load(fileobj)
-            except (pickle.UnpicklingError, OSError, IOError), ex:
+            except (pickle.UnpicklingError, OSError, IOError) as ex:
                 logging.error(u"Error reading cache file '{}': {} - {}".format(filename, type(ex), ex))
                 logging.error(u"os.stat: {}".format(os.stat(filename)))
 
@@ -143,9 +149,9 @@ class NWPDataAccess(object):
         filename = os.path.join(valid_time_cache, self.md5_filename(filename))
         if not os.path.exists(filename):
             try:
-                with open(filename, "w") as fileobj:
+                with open(filename, "wb") as fileobj:
                     pickle.dump(valid_times, fileobj)
-            except (pickle.PicklingError, OSError, IOError), ex:
+            except (pickle.PicklingError, OSError, IOError) as ex:
                 logging.error(u"Error writing cache file '{}': {} - {}".format(filename, type(ex), ex))
 
     def serviceCache(self):
@@ -178,7 +184,7 @@ class NWPDataAccess(object):
             if (cum_size_bytes > valid_time_cache_max_size_bytes) or fileage > valid_time_cache_max_age_seconds:
                 try:
                     os.remove(filename)
-                except (OSError, IOError), ex:
+                except (OSError, IOError) as ex:
                     logging.error(u"Could not remove {:}: {:} - {:}".format(filename, type(ex), ex))
                     logging.error(u"os.stat: {}".format(os.stat(filename)))
                 else:
@@ -211,6 +217,7 @@ class ECMWFDataAccess(NWPDataAccess):
         "medium_cloud_area_fraction": {"sfc": "SFC"},
         "high_cloud_area_fraction": {"sfc": "SFC"},
         "air_pressure_at_sea_level": {"sfc": "SFC"},
+        "emac_column_density": {"sfc": "SFC"},
         "surface_eastward_wind": {"sfc": "SFC"},
         "surface_northward_wind": {"sfc": "SFC"},
         "surface_air_pressure": {"sfc": "SFC"},
@@ -222,6 +229,7 @@ class ECMWFDataAccess(NWPDataAccess):
         "solar_elevation_angle": {"sfc": "SEA"},
         "air_pressure": {"ml": "P_derived",
                          "tl": "THETA_LEVELS",
+                         "pl": "PRESSURE_LEVELS",
                          "pv": "PVU"},
         "geopotential_height": {"ml": "Z_derived",
                                 "pl": "PRESSURE_LEVELS",
@@ -235,6 +243,9 @@ class ECMWFDataAccess(NWPDataAccess):
                                       "pl": "PRESSURE_LEVELS",
                                       "tl": "THETA_LEVELS"},
         "equivalent_latitude": {"pl": "PRESSURE_LEVELS"},
+        "number_of_wcb_trajectories": {"pl": "PRESSURE_LEVELS"},
+        "number_of_insitu_trajectories": {"pl": "PRESSURE_LEVELS"},
+        "number_of_mix_trajectories": {"pl": "PRESSURE_LEVELS"},
         "specific_cloud_liquid_water_content": {"ml": "CLWC"},
         "specific_cloud_ice_water_content": {"ml": "CIWC"},
         "specific_humidity": {"ml": "Q",
@@ -255,7 +266,8 @@ class ECMWFDataAccess(NWPDataAccess):
         "divergence_of_wind": {"ml": "D",
                                "pl": "PRESSURE_LEVELS"},
         "vertically_integrated_probability_of_wcb_occurrence": {"sfc": "ProbWCB_LAGRANTO_derived"},
-        "probability_of_wcb_occurrence": {"ml": "ProbWCB_LAGRANTO_derived"}
+        "probability_of_wcb_occurrence": {"ml": "ProbWCB_LAGRANTO_derived"},
+        "emac_R12": {"ml": "EMAC"}
         # "vertically_integrated_probability_of_wcb_occurrence": {"sfc": ("ProbWCB_LAGRANTO_derived", "ml")}
         # "": {"": ""},
     }
@@ -280,7 +292,7 @@ class ECMWFDataAccess(NWPDataAccess):
         # Compute the time step in hours from the forecast valid time
         # and the initialisation time.
         fc_step = valid_time - init_time
-        fc_step = fc_step.days * 24 + fc_step.seconds / 3600
+        fc_step = fc_step.days * 24 + fc_step.seconds // 3600
 
         # ECMWF forecasts are stored in a series of files containing
         # different time steps. Determine into which time step interval
@@ -291,7 +303,7 @@ class ECMWFDataAccess(NWPDataAccess):
                 break
 
         # Substitute variable identifiers in the template filename.
-        if variable_dict is not None and vartype not in variable_dict.keys():
+        if variable_dict is not None and vartype not in variable_dict:
             raise ValueError(u"variable type {} not available for variable {}"
                              .format(vartype, variable))
 
@@ -344,9 +356,9 @@ class ECMWFDataAccess(NWPDataAccess):
                 dtime = datetime.strptime(dtime, "%Y%m%d%H")
 
                 # Insert the filename into the tree.
-                if dtime not in filetree.keys():
+                if dtime not in filetree:
                     filetree[dtime] = {}
-                if step not in filetree[dtime].keys():
+                if step not in filetree[dtime]:
                     filetree[dtime][step] = {}
                 filetree[dtime][step][var] = filename
 
@@ -356,7 +368,7 @@ class ECMWFDataAccess(NWPDataAccess):
         """Returns a list of available forecast init times (base times).
         """
         filetree = self.build_filetree()
-        init_times = filetree.keys()
+        init_times = list(filetree.keys())
         init_times.sort()
         return init_times
 
@@ -377,15 +389,15 @@ class ECMWFDataAccess(NWPDataAccess):
             if os.path.exists(filename):
                 # If the file exists, open the file and read the contained
                 # times. Add the list of times to valid_times.
+                # ToDo remove caches
                 cached_valid_times = self.check_valid_cache(filename)
                 if cached_valid_times is not None:
                     valid_times.extend(cached_valid_times)
                 else:
-                    dataset = netCDF4.Dataset(filename)
-                    timename, timevar = netCDF4tools.identify_CF_time(dataset)
-                    times = netCDF4tools.num2date(timevar[:], timevar.units)
-                    valid_times.extend(times)
-                    dataset.close()
+                    with netCDF4.Dataset(filename) as dataset:
+                        timename, timevar = netCDF4tools.identify_CF_time(dataset)
+                        times = netCDF4tools.num2date(timevar[:], timevar.units)
+                        valid_times.extend(times)
                     self.save_valid_cache(filename, times)
 
         return valid_times
@@ -396,7 +408,7 @@ class ECMWFDataAccess(NWPDataAccess):
         """
         valid_times = set()
         filetree = self.build_filetree()
-        for init_time in filetree.keys():
+        for init_time in filetree:
             vtimes = self.get_valid_times(variable, vartype, init_time)
             valid_times.update(vtimes)
         return sorted(list(valid_times))
@@ -438,7 +450,7 @@ class GWFCDataAccess(ECMWFDataAccess):
     """
     _file_template = "$Y$m$d_$H_gravity_wave_forecast.{gridtype}.{domain_id}.{fc_step:03d}.{vartype}.nc"
     _file_regexp = "(?P<date>\d{8})_(?P<time>\d{2})_gravity_wave_forecast\.(?P<vartype>.*)\.%s\.(?P<step>\d{3}).*\.nc$"
-    _forecast_times = range(0, 150, 6)
+    _forecast_times = list(range(0, 150, 6))
     _data_organisation_table = {
         "gravity_wave_temperature_perturbation": {"ml": "ALTITUDE_LEVELS"},
         "air_pressure": {"ml": "ALTITUDE_LEVELS"},
@@ -513,12 +525,12 @@ class EMACDataAccess(NWPDataAccess):
         variable_dict = self._data_organisation_table[variable]
 
         # Substitute variable identifiers in the template filename.
-        if vartype not in variable_dict.keys():
+        if vartype not in variable_dict:
             raise ValueError(u"variable type {} not available for variable {}"
                              .format(vartype, variable))
 
         name = self._file_template % variable_dict[vartype]
-        if "replace" in variable_dict.keys():
+        if "replace" in variable_dict:
             pattern = variable_dict["replace"]
             name = name.replace(pattern[0], pattern[1])
         name = name.replace('$', '%')
@@ -538,7 +550,8 @@ class EMACDataAccess(NWPDataAccess):
             try:
                 dt = datetime.strptime(d, "%Y%m%d_%H")
                 init_times.append(dt)
-            except:
+            except Exception as ex:
+                logging.debug("Wildecard Exception %s - %s.", type(ex), ex)
                 pass
 
         init_times.sort()
@@ -565,11 +578,10 @@ class EMACDataAccess(NWPDataAccess):
                     if cached_valid_times is not None:
                         valid_times.extend(cached_valid_times)
                     else:
-                        dataset = netCDF4.Dataset(os.path.join(data_dir, filename))
-                        timename, timevar = netCDF4tools.identify_CF_time(dataset)
-                        times = netCDF4tools.num2date(timevar[:], timevar.units)
-                        valid_times.extend(times)
-                        dataset.close()
+                        with netCDF4.Dataset(os.path.join(data_dir, filename)) as dataset:
+                            timename, timevar = netCDF4tools.identify_CF_time(dataset)
+                            times = netCDF4tools.num2date(timevar[:], timevar.units)
+                            valid_times.extend(times)
                         self.save_valid_cache(filename, times)
 
         valid_times.sort()
@@ -637,10 +649,9 @@ class MeteosatDataAccess(NWPDataAccess):
 
             if match:
                 filename = os.path.join(self._root_path, f)
-                dataset = netCDF4.Dataset(filename)
-                timename, timevar = netCDF4tools.identify_CF_time(dataset)
-                init_time = netCDF4tools.num2date(0, timevar.units)
-                dataset.close()
+                with netCDF4.Dataset(filename) as dataset:
+                    timename, timevar = netCDF4tools.identify_CF_time(dataset)
+                    init_time = netCDF4tools.num2date(0, timevar.units)
 
                 init_times.append(init_time)
 
@@ -668,11 +679,10 @@ class MeteosatDataAccess(NWPDataAccess):
                 if cached_valid_times is not None:
                     valid_times.extend(cached_valid_times)
                 else:
-                    dataset = netCDF4.Dataset(filename)
-                    timename, timevar = netCDF4tools.identify_CF_time(dataset)
-                    times = netCDF4tools.num2date(timevar[:], timevar.units)
-                    valid_times.extend(times)
-                    dataset.close()
+                    with netCDF4.Dataset(filename) as dataset:
+                        timename, timevar = netCDF4tools.identify_CF_time(dataset)
+                        times = netCDF4tools.num2date(timevar[:], timevar.units)
+                        valid_times.extend(times)
                     self.save_valid_cache(filename, times)
 
         return valid_times
@@ -707,7 +717,7 @@ class MSSChemDataAccess(NWPDataAccess):
     def _create_data_table(self, vert):
         self._data_organisation_table = {
             stdname: {vert: shortname.lower()}
-            for stdname, (shortname, _, _, _) in MSSChemTargets.items()}
+            for stdname, (shortname, _, _, _) in list(MSSChemTargets.items())}
         self._data_organisation_table["air_pressure"] = {vert: "p"}
 
     def _determine_filename(self, variable, vartype, init_time, valid_time):
@@ -723,7 +733,7 @@ class MSSChemDataAccess(NWPDataAccess):
         variable_dict = self._data_organisation_table[variable]
 
         # Substitute variable identifiers in the template filename.
-        if vartype not in variable_dict.keys():
+        if vartype not in variable_dict:
             raise ValueError("variable type %s not available for variable %s"
                              % (vartype, variable))
 
@@ -763,9 +773,9 @@ class MSSChemDataAccess(NWPDataAccess):
                                    int(m.group("day")), int(m.group("hour")))
 
                 # Insert the filename into the tree.
-                if initime not in filetree.keys():
+                if initime not in filetree:
                     filetree[initime] = {}
-                if step not in filetree[initime].keys():
+                if step not in filetree[initime]:
                     filetree[initime][step] = {}
                 filetree[initime][step][var] = filename
 
@@ -775,7 +785,7 @@ class MSSChemDataAccess(NWPDataAccess):
         """Returns a list of available forecast init times (base times).
         """
         filetree = self.build_filetree()
-        init_times = filetree.keys()
+        init_times = list(filetree.keys())
         init_times.sort()
         return init_times
 
@@ -794,11 +804,10 @@ class MSSChemDataAccess(NWPDataAccess):
             if cached_valid_times is not None:
                 valid_times.extend(cached_valid_times)
             else:
-                dataset = netCDF4.Dataset(filename)
-                timename, timevar = netCDF4tools.identify_CF_time(dataset)
-                times = netCDF4tools.num2date(timevar[:], timevar.units)
-                valid_times.extend(times)
-                dataset.close()
+                with netCDF4.Dataset(filename) as dataset:
+                    timename, timevar = netCDF4tools.identify_CF_time(dataset)
+                    times = netCDF4tools.num2date(timevar[:], timevar.units)
+                    valid_times.extend(times)
                 self.save_valid_cache(filename, times)
 
         return valid_times
@@ -809,7 +818,7 @@ class MSSChemDataAccess(NWPDataAccess):
         """
         valid_times = set()
         filetree = self.build_filetree()
-        for init_time in filetree.keys():
+        for init_time in filetree:
             vtimes = self.get_valid_times(variable, vartype, init_time)
             valid_times.update(vtimes)
         return sorted(list(valid_times))
