@@ -26,11 +26,16 @@
     See the License for the specific language governing permissions and
     limitations under the License.
 """
-
-
 # style definitions should be put in mpl_hsec_styles.py
 
-import StringIO
+from __future__ import division
+
+
+from future import standard_library
+standard_library.install_aliases()
+
+
+import io
 import logging
 from abc import abstractmethod
 import mss_wms_settings
@@ -47,6 +52,10 @@ from mslib.mswms import mss_2D_sections
 from mslib.utils import get_projection_params
 
 
+BASEMAP_CACHE = {}
+BASEMAP_REQUESTS = []
+
+
 class AbstractHorizontalSectionStyle(mss_2D_sections.Abstract2DSectionStyle):
     """Abstract horizontal section super class. Use this class as a parent
        to classes implementing different plotting backends. For example,
@@ -68,18 +77,18 @@ class MPLBasemapHorizontalSectionStyle(AbstractHorizontalSectionStyle):
     name = "BASEMAP"
     title = "Matplotlib basemap"
 
-    def _plot_style(self, style=None):
+    def _plot_style(self):
         """Overwrite this method to plot style-specific data on the map.
         """
         pass
 
     def supported_epsg_codes(self):
-        return mss_wms_settings.epsg_to_mpl_basemap_table.keys()
+        return list(mss_wms_settings.epsg_to_mpl_basemap_table.keys())
 
     def support_epsg_code(self, epsg):
         """Returns a list of supported EPSG codes.
         """
-        return (epsg in mss_wms_settings.epsg_to_mpl_basemap_table.keys() or
+        return (epsg in mss_wms_settings.epsg_to_mpl_basemap_table or
                 get_projection_params(str(epsg)) is not None)
 
     def supported_crs(self):
@@ -172,17 +181,17 @@ class MPLBasemapHorizontalSectionStyle(AbstractHorizontalSectionStyle):
         spacingValues = [0.05, 0.1, 0.25, 0.5, 1, 2, 5, 10, 20, 30, 40]
         deltaLon = mapLonStop - mapLonStart
         deltaLat = mapLatStop - mapLatStart
-        spacingLon = [i for i in spacingValues if i > deltaLon / 10.][0]
-        spacingLat = [i for i in spacingValues if i > deltaLat / 10.][0]
+        spacingLon = [i for i in spacingValues if i > (deltaLon / 10.)][0]
+        spacingLat = [i for i in spacingValues if i > (deltaLat / 10.)][0]
 
         #   c) parallels and meridians start at the first value in the
         #      spacingLon/Lat grid that's smaller than the lon/lat of the
         #      lower left corner; they stop at the first values in the
         #      grid that's larger than the lon/lat of the upper right corner.
-        lonStart = np.floor(mapLonStart / spacingLon) * spacingLon
-        lonStop = np.ceil(mapLonStop / spacingLon) * spacingLon
-        latStart = np.floor(mapLatStart / spacingLat) * spacingLat
-        latStop = np.ceil(mapLatStop / spacingLat) * spacingLat
+        lonStart = np.floor((mapLonStart / spacingLon)) * spacingLon
+        lonStop = np.ceil((mapLonStop / spacingLon)) * spacingLon
+        latStart = np.floor((mapLatStart / spacingLat)) * spacingLat
+        latStop = np.ceil((mapLatStop / spacingLat)) * spacingLat
 
         #   d) call the basemap methods to draw the lines in the determined
         #      range.
@@ -197,13 +206,14 @@ class MPLBasemapHorizontalSectionStyle(AbstractHorizontalSectionStyle):
 
     def plot_hsection(self, data, lats, lons, bbox=(-180, -90, 180, 90),
                       level=None, figsize=(960, 640), epsg=None,
-                      proj_params={"projection": "cyl"},
+                      proj_params=None,
                       valid_time=None, init_time=None, style=None,
                       resolution=-1, noframe=False, show=False,
                       transparent=False):
         """
         EPSG overrides proj_params!
         """
+        proj_params = proj_params or {"projection": "cyl"}
         # Projection parameters from EPSG code.
         if epsg is not None:
             proj_params = mss_wms_settings.epsg_to_mpl_basemap_table.get(epsg)
@@ -216,7 +226,7 @@ class MPLBasemapHorizontalSectionStyle(AbstractHorizontalSectionStyle):
 
         # Check if required data is available.
         for datatype, dataitem in self.required_datafields:
-            if dataitem not in data.keys():
+            if dataitem not in data:
                 raise KeyError(u"required data field '{}' not found".format(dataitem))
 
         # Copy parameters to properties.
@@ -237,7 +247,7 @@ class MPLBasemapHorizontalSectionStyle(AbstractHorizontalSectionStyle):
 
         logging.debug("creating figure..")
         dpi = 80
-        figsize = figsize[0] / dpi, figsize[1] / dpi
+        figsize = (figsize[0] / dpi), (figsize[1] / dpi)
         facecolor = "white"
         fig = mpl.figure.Figure(figsize=figsize, dpi=dpi, facecolor=facecolor)
         logging.debug("\twith frame and legends" if not noframe else
@@ -263,10 +273,43 @@ class MPLBasemapHorizontalSectionStyle(AbstractHorizontalSectionStyle):
         # stretch a map into an image area of a different aspect ratio."
         # NOTE: While the MSUI always requests image sizes that match the aspect
         # ratio, for instance the Metview 4 client does not (mr, 2011Dec16).
-        bm = basemap.Basemap(llcrnrlon=bbox[0], llcrnrlat=bbox[1],
-                             urcrnrlon=bbox[2], urcrnrlat=bbox[3],
-                             resolution='l', area_thresh=1000., ax=ax,
-                             fix_aspect=(not noframe), **proj_params)
+
+        # Some additional code to store the last 20 coastlines in memory for quicker
+        # access.
+        key = repr((proj_params, bbox))
+        basemap_use_cache = getattr(mss_wms_settings, "basemap_use_cache", False)
+        basemap_request_size = getattr(mss_wms_settings, "basemap_request_size ", 200)
+        basemap_cache_size = getattr(mss_wms_settings, "basemap_cache_size", 20)
+        if basemap_use_cache and key in BASEMAP_CACHE:
+            bm = basemap.Basemap(llcrnrlon=bbox[0], llcrnrlat=bbox[1],
+                                 urcrnrlon=bbox[2], urcrnrlat=bbox[3],
+                                 resolution=None, area_thresh=1000., ax=ax,
+                                 fix_aspect=(not noframe), **proj_params)
+            (bm.resolution, bm.coastsegs, bm.coastpolygontypes, bm.coastpolygons,
+             bm.coastsegs, bm.landpolygons, bm.lakepolygons, bm.cntrysegs) = BASEMAP_CACHE[key]
+            logging.debug("Loaded {} from basemap cache".format(key))
+        else:
+            bm = basemap.Basemap(llcrnrlon=bbox[0], llcrnrlat=bbox[1],
+                                 urcrnrlon=bbox[2], urcrnrlat=bbox[3],
+                                 resolution='l', area_thresh=1000., ax=ax,
+                                 fix_aspect=(not noframe), **proj_params)
+            # read in countries manually, as those are laoded only on demand
+            bm.cntrysegs, _ = bm._readboundarydata("countries")
+            if basemap_use_cache:
+                BASEMAP_CACHE[key] = (bm.resolution, bm.coastsegs, bm.coastpolygontypes, bm.coastpolygons,
+                                      bm.coastsegs, bm.landpolygons, bm.lakepolygons, bm.cntrysegs)
+        if basemap_use_cache:
+            BASEMAP_REQUESTS.append(key)
+            BASEMAP_REQUESTS[:] = BASEMAP_REQUESTS[-basemap_request_size:]
+
+            if len(BASEMAP_CACHE) > basemap_cache_size:
+                useful = {}
+                for idx, key in enumerate(BASEMAP_REQUESTS):
+                    useful[key] = useful.get(key, 0) + idx
+                least_useful = sorted([(value, key) for key, value in list(useful.items())])[:-basemap_cache_size]
+                for _, key in least_useful:
+                    del BASEMAP_CACHE[key]
+                    BASEMAP_REQUESTS[:] = [_x for _x in BASEMAP_REQUESTS if key != _x]
 
         # Set up the map appearance.
         bm.drawcoastlines(color='0.25')
@@ -295,7 +338,7 @@ class MPLBasemapHorizontalSectionStyle(AbstractHorizontalSectionStyle):
 
         # Return the image as png embedded in a StringIO stream.
         canvas = FigureCanvas(fig)
-        output = StringIO.StringIO()
+        output = io.BytesIO()
         canvas.print_png(output, bbox_inches='tight')
 
         if show:
@@ -316,7 +359,7 @@ class MPLBasemapHorizontalSectionStyle(AbstractHorizontalSectionStyle):
         output.seek(0)  # necessary for PIL.Image.open()
         palette_img = PIL.Image.open(output).convert(mode="RGB"
                                                      ).convert("P", palette=PIL.Image.ADAPTIVE)
-        output = StringIO.StringIO()
+        output = io.BytesIO()
         if not transparent:
             logging.debug("saving figure as non-transparent PNG.")
             palette_img.save(output, format="PNG")  # using optimize=True doesn't change much
@@ -331,7 +374,7 @@ class MPLBasemapHorizontalSectionStyle(AbstractHorizontalSectionStyle):
             # palette. (Why doesn't PIL provide a method to directly access the
             # colours in a palette??)
             lut = palette_img.resize((256, 1))
-            lut.putdata(range(256))
+            lut.putdata(list(range(256)))
             lut = [c[1] for c in lut.convert("RGB").getcolors()]
             facecolor_rgb = list(mpl.colors.hex2color(mpl.colors.cnames[facecolor]))
             for i in [0, 1, 2]:
@@ -368,7 +411,7 @@ class MPLBasemapHorizontalSectionStyle(AbstractHorizontalSectionStyle):
         self.lons = self.lons[lon_indices]
 
         # Shift data fields correspondingly.
-        for key in self.data.keys():
+        for key in self.data:
             self.data[key] = self.data[key][:, lon_indices]
 
     def mask_data(self):
@@ -386,8 +429,8 @@ class MPLBasemapHorizontalSectionStyle(AbstractHorizontalSectionStyle):
         x, y = self.bm(lonmesh_, latmesh_)
         # test which coordinates are outside the map domain.
 
-        add_x = (self.bm.xmax - self.bm.xmin) / 10.
-        add_y = (self.bm.ymax - self.bm.ymin) / 10.
+        add_x = ((self.bm.xmax - self.bm.xmin) / 10.)
+        add_y = ((self.bm.ymax - self.bm.ymin) / 10.)
 
         mask1 = x < self.bm.xmin - add_x
         mask2 = x > self.bm.xmax + add_x
@@ -395,6 +438,6 @@ class MPLBasemapHorizontalSectionStyle(AbstractHorizontalSectionStyle):
         mask4 = y < self.bm.ymin - add_y
         mask = mask1 + mask2 + mask3 + mask4
         # mask data arrays.
-        for key in self.data.keys():
+        for key in self.data:
             self.data[key] = np.ma.masked_array(self.data[key],
                                                 mask=mask, keep_mask=False)
