@@ -27,6 +27,10 @@
 """
 
 from __future__ import absolute_import
+from __future__ import division
+
+from builtins import str
+
 import csv
 import mslib.msui.flighttrack as ft
 
@@ -40,14 +44,14 @@ def save_to_csv(filename, name, waypoints):
         csv_writer.writerow(["Index", "Location", "Lat (+-90)", "Lon (+-180)", "Flightlevel", "Pressure (hPa)",
                              "Leg dist. (km)", "Cum. dist. (km)", "Comments"])
         for i, wp in enumerate(waypoints):
-            loc = unicode(wp.location).encode("ascii", "replace")
+            loc = str(wp.location).encode("ascii", "replace")
             lat = "{:.3f}".format(wp.lat)
             lon = "{:.3f}".format(wp.lon)
             lvl = "{:.3f}".format(wp.flightlevel)
             pre = "{:.3f}".format(wp.pressure / 100.)
             leg = "{:.3f}".format(wp.distance_to_prev)
             cum = "{:.3f}".format(wp.distance_total)
-            com = unicode(wp.comments).encode("ascii", "replace")
+            com = str(wp.comments).encode("ascii", "replace")
             csv_writer.writerow([i, loc, lat, lon, lvl, pre, leg, cum, com])
 
 
@@ -59,8 +63,8 @@ def load_from_csv(filename):
         raise SyntaxError("CSV file requires at least 4 lines!")
     dialect = csv.Sniffer().sniff(lines[-1])
     csv_reader = csv.reader(lines, dialect=dialect)
-    name = csv_reader.next()[0]
-    csv_reader.next()  # header
+    name = next(csv_reader)[0]
+    next(csv_reader)  # header
     for row in csv_reader:
         wp = ft.Waypoint()
         wp.location = row[1]
